mainMessage = """
------------Expense tracker---------------
0. Help
1. Add string
2. Find month
3. Display all
4. Display grouped data
5. Currencies
6. Local convertor
7. Clear data
8. Quit
------------------------------------------
"""
helpMessage = """
----Description for all commands here:----
0. Help
1. Add a new value for finance array
2. Find all items based on month in array
3. Display all items in array
4. Display grouped data by months
5. List of all available currencies \n  at Forex exchange at current moment
6. Local currency convertor
7. Clear all data from array
8. Quit app
9. Credits
------------------------------------------
"""
creditsMessage = """
------------------------------------------
  Expense tracker python CLI app made by
            Vladimir Kobranov
            
    https://github.com/VladimirKobranov
------------------------------------------
        Release Date: 2023-07-10
          Version Number: 1.3.0.0
             Release Notes:
--added conversion at Forex Exchange Market
--added local currency convertor
--added input checks
--added program name title
--added delete string functionality 
--overhaul, fixes
--packed to pip
------------------------------------------
"""
availableCurrencies = """
---------------------------------------------------------
             Available currencies:
EUR - Euro Member Countries    CHF - Switzerland Franc
IDR - Indonesia Rupiah         KRW - Korea (South) Won
BGN - Bulgaria Lev             CNY - China Yuan Renminbi
ILS - Israel Shekel            TRY - Turkey Lira
GBP - United Kingdom Pound     HRK - Croatia Kuna
DKK - Denmark Krone            NZD - New Zealand Dollar
CAD - Canada Dollar            THB - Thailand Baht
JPY - Japan Yen                USD - United States Dollar
HUF - Hungary Forint           NOK - Norway Krone
RON - Romania New Leu          RUB - Russia Ruble --not available
MYR - Malaysia Ringgit         INR - India Rupee
SEK - Sweden Krona             MXN - Mexico Peso
SGD - Singapore Dollar         CZK - Czech Republic Koruna
HKD - Hong Kong Dollar         BRL - Brazil Real
AUD - Australia Dollar         PLN - Poland Zloty
PHP - Philippines Peso         ZAR - South Africa Rand
---------------------------------------------------------
"""
currency_list = ['EUR', 'IDR', 'BGN', 'ILS', 'GBP', 'DKK', 'CAD', 'JPY', 'HUF', 'RON',
                 'MYR', 'SEK', 'SGD', 'HKD', 'AUD', 'CHF', 'KRW', 'CNY', 'TRY', 'HRK',
                 'NZD', 'THB', 'USD', 'NOK', 'RUB', 'INR', 'MXN', 'CZK', 'BRL', 'PLN', 'PHP', 'ZAR']



def delete_string(finances_list):
    def print_data():
        if len(finances_list) == 0:
            print('List is empty!')
        else:
            print('---------Displaying all strings:----------\n')
            for i, item in enumerate(finances_list, start=1):
                print(f"{i}. {item}")
            print()

    print_data()
    choice = input('Delete string? (y/n): ')
    while choice.lower() in ['yes', 'y']:
        index = int(input('Choose index: '))
        if 1 <= index <= len(finances_list):
            finances_list.pop(index - 1)
            print('String deleted successfully!\n')
            print_data()
            choice = input('Delete another one? (y/n): ')
        else:
            print('Invalid index!')
    print('\nReturning...')



# from logic.grouped_data import grouped_final
# from logic.input_data import input_string
# from logic import local_convertor
# from logic import search_by_month_data
# from logic import show_all_delete_string
# from logic import terminal_name
# from logic import text_prompts
# from data import *



# from . import grouped_data
# from . import input_data
# from . import local_convertor
# from . import search_by_month_data
# from . import show_all_delete_string
# from . import terminal_name
# from . import text_prompts


from .grouped_data import grouped_final
from .input_data import input_string
from .local_convertor import local_convertor
from .search_by_month_data import search_by_month
from .show_all_delete_string import delete_string
from .terminal_name import set_terminal_title, get_terminal_title
from .text_prompts import mainMessage, helpMessage, creditsMessage, availableCurrencies, currency_list



import sys


def set_terminal_title(title):
    if sys.platform.startswith('win32'):
        # For Windows
        import ctypes
        ctypes.windll.kernel32.SetConsoleTitleW(title)
    else:
        # For Linux, macOS, and other Unix-like systems
        sys.stdout.write(f"\033]0;{title}\a")
        sys.stdout.flush()


def get_terminal_title():
    if sys.platform.startswith('win32'):
        # For Windows
        import ctypes
        buff = ctypes.create_unicode_buffer(1024)
        ctypes.windll.kernel32.GetConsoleTitleW(buff, len(buff))
        return buff.value
    else:
        # For Linux, macOS, and other Unix-like systems
        return ""



from datetime import datetime


def search_by_month(finances_list):
    keyword = input("Enter month (leave empty for current month): ")
    print()
    if not keyword:
        keyword = datetime.now().strftime("%B")

    matched_strings = []
    for string in finances_list:
        date_str = string.split('---')[0]
        date = datetime.strptime(date_str, "%Y-%m-%d")
        month = date.strftime("%B")
        month_number = date.strftime("%m")
        if month.lower() == keyword.lower() or month.startswith(
                keyword.capitalize()) or month_number == keyword:
            matched_strings.append(string)

    if len(matched_strings) == 0:
        print('No matching strings found')
    else:
        print(f"Matched strings for month '{keyword}':\n")
        for i, string in enumerate(matched_strings, start=1):
            print(f"{i:2}. {string}")
    print()



from datetime import datetime


def input_string(finances_list, currency):
    n_value = input('Enter a value: ')
    if n_value == '':
        n_value = 0
    else:
        n_value = float(n_value)
    while n_value <= 0:
        while True:
            n_value = float(input('Enter a value more than 0: '))
            try:
                float(n_value)
                break
            except ValueError:
                print('Enter only numbers\n')
    new_expense = input('Expense or income: ')
    if new_expense in ['expense', 'e', 't', 'true', 'exp']:
        expense_income = 'Expense'
    else:
        expense_income = 'Income'
    input_date = input("Enter a date (YY MM DD or leave it empty(now)): ")
    input_date = input_date.replace(" ", "")
    if not input_date or input_date.lower() in ["now", "today"]:
        n_date = datetime.now()
    else:
        n_date = datetime.strptime(input_date, "%y%m%d")
    formatted_date = n_date.strftime("%Y-%m-%d")
    n_description = input('Write a description: ')
    if n_description == '':
        n_description = 'empty description'
    finances_list.append(f'{formatted_date}---{expense_income}---{n_value}---{currency}---{n_description}')
    print()
    print(f'Added: {formatted_date}---{expense_income}---{n_value}---{currency}---{n_description}')
